@@ -84,7 +84,7 @@
 #define KIDLETIME_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIDLETIME_NO_DEPRECATED
-#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
 #endif
 #ifdef KIDLETIME_NO_DEPRECATED_WARNINGS
 #  define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIDLETIME_DEPRECATED_WARNINGS_SINCE KIDLETIME_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KIDLETIME_DEPRECATED_WARNINGS_SINCE 0x57200
 #  endif
 #endif
 
